@@ -7,7 +7,7 @@ from dagster import Field, In, Noneable, Nothing, OpExecutionContext, Permissive
 from dagster._annotations import experimental
 from dagster._utils.merger import merge_dicts
 
-from ..client import DagsterKubernetesClient
+from ..client import DEFAULT_JOB_POD_COUNT, DagsterKubernetesClient
 from ..container_context import K8sContainerContext
 from ..job import DagsterK8sJobConfig, construct_dagster_k8s_job, get_k8s_job_name
 from ..launcher import K8sRunLauncher
@@ -131,8 +131,7 @@ def execute_k8s_job(
     job_metadata: Optional[Dict[str, Any]] = None,
     job_spec_config: Optional[Dict[str, Any]] = None,
 ):
-    """
-    This function is a utility for executing a Kubernetes job from within a Dagster op.
+    """This function is a utility for executing a Kubernetes job from within a Dagster op.
 
     Args:
         image (str): The image in which to launch the k8s job.
@@ -332,23 +331,27 @@ def execute_k8s_job(
 
         try:
             log_entry = next(log_stream)
-            print(log_entry)  # pylint: disable=print-call
+            print(log_entry)  # noqa: T201
         except StopIteration:
             break
 
+    if job_spec_config and job_spec_config.get("parallelism"):
+        num_pods_to_wait_for = job_spec_config["parallelism"]
+    else:
+        num_pods_to_wait_for = DEFAULT_JOB_POD_COUNT
     api_client.wait_for_running_job_to_succeed(
         job_name=job_name,
         namespace=namespace,
         wait_timeout=timeout,
         start_time=start_time,
+        num_pods_to_wait_for=num_pods_to_wait_for,
     )
 
 
 @op(ins={"start_after": In(Nothing)}, config_schema=K8S_JOB_OP_CONFIG)
 @experimental
 def k8s_job_op(context):
-    """
-    An op that runs a Kubernetes job using the k8s API.
+    """An op that runs a Kubernetes job using the k8s API.
 
     Contrast with the `k8s_job_executor`, which runs each Dagster op in a Dagster job in its
     own k8s job.
